Stampati — SoL 4, manuale utente

# Stampati

Suggerimento

A partire dalla versione 3.33, la maggior parte delle stampe mostra un QRCode sulla prima pagina che contiene l’hyperlink alla corrispondente pagina Lit. Il QRCode può essere letto su uno smartphone con una delle svariate applicazioni gratuite disponibili, piuttosto che semplicemente cliccato quando il PDF viene visualizzato su un computer tradizionale.

Il QRCode non appare quando viene usato l’indirizzo `localhost` per accedere all’istanza locale di SoL. Per farlo apparire, devi usare l’indirizzo IP del computer: quando possibile, SoL lo mostra alla partenza:

    Your IP address seems to be 192.168.1.100
    Starting server in PID 8131.
    serving on http://0.0.0.0:6996

Invece che usare l’URL `http://localhost:6996/` per accedere a SoL, utilizza `http://192.168.1.100:6996/` e il QRCode dovrebbe apparire ed essere utilizzabile da altri dispositivi connessi alla tua rete locale.

## Concorrenti

## Tessere

## Cartellini

## Risultati

## Classifica